#!/bin/bash
#
# Copyright 2016-2017 Huawei Technologies Co., Ltd.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# autorelease root dir
ROOT=`git rev-parse --show-toplevel`/autorelease
VERSION="1.1.0-SNAPSHOT"

BUILD_DIR=$ROOT/build

mkdir -p $BUILD_DIR
cd $BUILD_DIR

FILE=$BUILD_DIR/pom-raw.xml

cat > $FILE <<EOF
<!--
   Copyright (c) 2016-2017 Huawei Technologies Co., Ltd.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
-->
<!-- AUTOGENERATED by generate-pom.sh; DO NOT MODIFY MANUALLY -->
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
  <modelVersion>4.0.0</modelVersion>
  <parent>
    <groupId>org.openo.oparent</groupId>
    <artifactId>oparent</artifactId>
    <version>$VERSION</version>
    <relativePath>oparent</relativePath>
  </parent>
  <groupId>org.openo.integration.distribution</groupId>
  <artifactId>openo</artifactId>
  <packaging>pom</packaging>
  <modules>
EOF

find -mindepth 1 -type d -exec test -e "{}/pom.xml" ';' -prune -printf "%P\n" | sort | while read p; do
    if [ $p != "integration/autorelease/build" ]; then
	cat >> $FILE <<EOF
    <module>$p</module>
EOF
    fi
done

cat >> $FILE <<EOF
  </modules>
  <dependencies>
EOF

$ROOT/scripts/generate-binary-deps.py >> $FILE

cat >> $FILE <<EOF
  </dependencies>

  <build>
    <plugins>
      <plugin>
        <artifactId>maven-assembly-plugin</artifactId>
        <version>2.6</version>
        <configuration>
          <appendAssemblyId>true</appendAssemblyId>
          <descriptors>
            <descriptor>assembly.xml</descriptor>
          </descriptors>
        </configuration>
        <executions>
          <execution>
            <id>make-assembly</id>
            <phase>package</phase>
            <goals>
              <goal>single</goal>
            </goals>
          </execution>
        </executions>
      </plugin>
    </plugins>
  </build>

</project>
EOF

xmlstarlet fo pom-raw.xml > pom.xml
rm -f pom-raw.xml

$ROOT/scripts/generate-assembly.py > $BUILD_DIR/assembly.xml
